@@ -6,11 +6,9 @@
 #' The [auto_tuner()] function creates an [AutoTuner] object.
 #'
 #' @section Validation:
-#' Both, the tuned [mlr3::Learner] and the `AutoTuner` itself can make use of validation data.
-#' the `$validate` field of the `AutoTuner` determines how validation is done during the final model fit.
-#' In most cases, this should be left as `NULL`.
-#' The `$validate` field of the tuned [mlr3::Learner] specifies how the validation data is constructed
-#' during the hyperparameter optimization.
+#' The `AutoTuner` itself does **not** have the `"validation"` property.
+#' To enable validation during the tuning, set the `$validate` field of the tuned learner.
+#' This is also possible via `set_validate()`.
 #'
 #' @details
 #' The [AutoTuner] is a [mlr3::Learner] which wraps another [mlr3::Learner] and performs the following steps during `$train()`:
@@ -54,7 +52,6 @@
 #' @template param_check_values
 #' @template param_callbacks
 #' @template param_rush
-#' @template param_validate
 #'
 #' @export
 #' @examples
@@ -145,8 +142,7 @@ AutoTuner = R6Class("AutoTuner",
       store_models = FALSE,
       check_values = FALSE,
       callbacks = NULL,
-      rush = NULL,
-      validate = NULL
+      rush = NULL
       ) {
       learner = assert_learner(as_learner(learner, clone = TRUE))
 
@@ -170,7 +166,6 @@ AutoTuner = R6Class("AutoTuner",
       ia$callbacks = assert_callbacks(as_callbacks(callbacks))
       if (!is.null(rush)) ia$rush = assert_class(rush, "Rush")
       self$instance_args = ia
-      private$.can_validate = "validation" %in% learner$properties
 
       super$initialize(
         id = paste0(learner$id, ".tuned"),
@@ -178,9 +173,8 @@ AutoTuner = R6Class("AutoTuner",
         packages = c("mlr3tuning", learner$packages),
         feature_types = learner$feature_types,
         predict_types = learner$predict_types,
-        properties = setdiff(learner$properties, "internal_tuning")
+        properties = setdiff(learner$properties, c("internal_tuning", "validation"))
       )
-      self$validate = validate
       self$predict_type = learner$predict_type
       self$predict_sets = learner$predict_sets
     },
@@ -301,19 +295,6 @@ AutoTuner = R6Class("AutoTuner",
       self$state$internal_valid_scores
     },
 
-    #' @field validate
-    #' How to construct the internal validation data. This parameter can be either `NULL`,
-    #' a ratio in $(0, 1)$, `"test"`, or `"predefined"`.
-    validate = function(rhs) {
-      if (!missing(rhs)) {
-        if (!private$.can_validate && !is.null(rhs)) {
-          stopf("The learner that is tuned by AutoTuner '%s' does not support validation", self$id)
-        }
-        private$.validate = assert_validate(rhs)
-      }
-      private$.validate
-    },
-
     #' @field archive [ArchiveBatchTuning]\cr
     #' Archive of the [TuningInstanceBatchSingleCrit].
     archive = function() self$tuning_instance$archive,
@@ -360,7 +341,7 @@ AutoTuner = R6Class("AutoTuner",
     #' Hash (unique identifier) for this object.
     hash = function(rhs) {
       assert_ro_binding(rhs)
-      calculate_hash(class(self), self$id, self$param_set$values, private$.predict_type, self$fallback$hash, self$parallel_predict, self$tuner, self$instance_args, private$.store_tuning_instance, private$.validate)
+      calculate_hash(class(self), self$id, self$param_set$values, private$.predict_type, self$fallback$hash, self$parallel_predict, self$tuner, self$instance_args, private$.store_tuning_instance)
     },
 
     #' @field phash (`character(1)`)\cr
@@ -372,20 +353,12 @@ AutoTuner = R6Class("AutoTuner",
   ),
 
   private = list(
-    .validate = NULL,
-    .can_validate = NULL,
     .train = function(task) {
       # construct instance from args; then tune
       ia = self$instance_args
       ia$task = task
 
-      validate = get0("validate", ia$learner)
-      if (is.numeric(validate) || identical(validate, "test") && !is.null(task$internal_valid_task)) {
-        # we temporarily remove the internal validation task, because we need to overwrite it
-        prev_valid_task = task$internal_valid_task
-        task$internal_valid_task = NULL
-        on.exit({task$internal_valid_task = prev_valid_task})
-      }
+      learner = ia$learner$clone(deep = TRUE)
 
       # check if task contains all row ids required for instantiated resampling
       if (ia$resampling$is_instantiated) {
@@ -406,22 +379,16 @@ AutoTuner = R6Class("AutoTuner",
       instance = do.call(TuningInstance$new, ia)
       self$tuner$optimize(instance)
 
-      # now we reset the validation task
-      on.exit()
-
-      # get learner, set params to optimal, then train we REALLY need to clone
-      # here we write to the object and this would change instance_args
-      learner = ia$learner$clone(deep = TRUE)
-
-      if (private$.can_validate) {
-        set_validate(learner, self$validate)
-      }
+      # now we reset the validation task and clear the exit handlers
 
       # in the case of internal tuning, the result_learner_param_vals already contains the aggregated internally
       learner$param_set$values = instance$result_learner_param_vals
       # disable timeout to allow train on full data set without time limit
       # timeout during tuning is not affected
       learner$timeout = c(train = Inf, predict = Inf)
+      if ("validation" %in% learner$properties) {
+        set_validate(learner, validate = NULL)
+      }
       learner$train(task)
 
       # the return model is a list of "learner" and "tuning_instance"
@@ -492,17 +459,12 @@ unmarshal_model.auto_tuner_model_marshaled = function(model, inplace = FALSE, ..
 #' @title Configure Validation for AutoTuner
 #'
 #' @description
-#' Configure validation for the final model fit (`final_validate`), as well as
-#' during the tuning (`validate`).
+#' Configure validation data for the learner that is tuned by the `AutoTuner`.
 #'
 #' @param learner ([`AutoTuner`])\cr
 #'   The autotuner for which to enable validation.
 #' @param validate (`numeric(1)`, `"predefined"`, `"test"`, or `NULL`)\cr
 #'   How to configure the validation during the hyperparameter tuning.
-#' @param final_validate (`numeric(1)`, `"predefined"`, `"test"` or `NULL`)\cr
-#'   How to configure the validation during the final model fit.
-#'   The default behavior is to not change the value.
-#'   Rarely needed.
 #' @param ... (any)\cr
 #'   Passed when calling `set_validate()` on the wrapped leaerner.
 #' @export
@@ -516,10 +478,7 @@ unmarshal_model.auto_tuner_model_marshaled = function(model, inplace = FALSE, ..
 #' # use the test set as validation data during tuning
 #' set_validate(at, validate = "test")
 #' at$learner$validate
-set_validate.AutoTuner = function(learner, validate, final_validate, ...) {
-  if (!missing(final_validate)) {
-    learner$validate = final_validate
-  }
+set_validate.AutoTuner = function(learner, validate, ...) {
   set_validate(learner$learner, validate = validate, ...)
   invisible(learner)
 }
