@@ -140,68 +140,6 @@ load_callback_async_measures = function() {
 #' }
 NULL
 
-# we need this as a callback, because we cannot overwrite the private$.assign_result method from the Tuner,
-# because for TunerFromOptimizer this method is never called
-load_callback_internal_tuning = function(batch) {
-
-  on_result = function(callback, context) {
-    inst = context$instance
-    internal_tuned_values = inst$archive$best()[, "internal_tuned_values", with = FALSE]$internal_tuned_values
-
-    # right now, this contains the values tuned by the optimizer and the values that were set in the learner
-    learner_param_vals = context$result$learner_param_vals
-    # we now have to:
-    # * add the internally optimized values
-    # * disable the internal tuning for the internally optimized values
-
-    learner = inst$objective$learner
-    new_learner_param_vals = pmap(list(itv = internal_tuned_values, lpv = learner_param_vals), function(itv, lpv) {
-      prev_pvs = learner$param_set$values
-
-      learner$param_set$values = insert_named(lpv, itv)
-      on.exit({
-        inst$objective$learner$param_set$values = prev_pvs
-      })
-
-      learner$param_set$disable_internal_tuning(context$instance$internal_search_space$ids())
-      nlpv = inst$objective$learner$param_set$values
-      on.exit()
-
-      nlpv
-    })
-    context$result[, let(learner_param_vals = new_learner_param_vals, internal_tuned_values = internal_tuned_values)]
-  }
-
-  if (batch) {
-    callback_batch_tuning("mlr3tuning.batch_internal_tuning",
-      man = "mlr3tuning::internal_tuning",
-      on_eval_before_archive = function(callback, context) {
-        new_uhashes = tail(context$benchmark_result$uhashes, n = nrow(context$aggregated_performance))
-
-        internal_tuned_values_aggr = map(new_uhashes, function(uhash) {
-          states = get_private(context$benchmark_result)$.data$learner_states(uhash)
-
-          internal_tuned_values = transpose_list(map(states, "internal_tuned_values"))
-          context$instance$internal_search_space$aggr_internal_tuned_values(internal_tuned_values)
-        })
-        context$aggregated_performance[, let(internal_tuned_values = internal_tuned_values_aggr)]
-      },
-      on_result = on_result
-    )
-  } else {
-    callback_async_tuning("mlr3tuning.async_internal_tuning",
-      on_eval_before_archive = function(callback, context) {
-        states = get_private(context$resample_result)$.data$learner_states()
-        itvs = transpose_list(map(states, "internal_tuned_values"))
-        internal_tuned_values_aggr = context$instance$internal_search_space$aggr_internal_tuned_values(itvs)
-        # here, aggregated_performance is a list not a data.table
-        context$aggregated_performance$internal_tuned_values = list(internal_tuned_values_aggr)
-      },
-      on_result = on_result
-    )
-  }
-}
-
 load_callback_async_mlflow = function() {
   callback_async_tuning("mlr3tuning.async_mlflow",
     label = "MLflow Connector",
@@ -285,20 +223,10 @@ load_callback_async_default_configuration = function() {
       # parameters with exp transformation and log inverse transformation
       # parameters with unknown inverse transformation
       # parameter set with trafo
-      if ("set_id" %in% names(ps())) {
-        # old paradox
-        has_logscale = map_lgl(instance$search_space$params, function(param) get_private(param)$.has_logscale)
+      has_logscale = map_lgl(instance$search_space$params$.trafo, function(x) identical(x, exp))
+      has_trafo = map_lgl(instance$search_space$params$.trafo, function(x) !is.null(x) && !identical(x, exp))
+      has_extra_trafo = !is.null(instance$search_space$extra_trafo)
 
-        has_trafo = map_lgl(instance$search_space$params, function(param) get_private(param)$.has_trafo)
-
-        has_extra_trafo = get_private(instance$search_space)$.has_extra_trafo
-      } else {
-        has_logscale = map_lgl(instance$search_space$params$.trafo, function(x) identical(x, exp))
-
-        has_trafo = map_lgl(instance$search_space$params$.trafo, function(x) !is.null(x) && !identical(x, exp))
-
-        has_extra_trafo = !is.null(instance$search_space$extra_trafo)
-      }
 
       if (any(has_trafo) || has_extra_trafo) {
         stop("Cannot evaluate default hyperparameter values. Search space contains transformation functions with unknown inverse function.")
@@ -325,20 +253,9 @@ load_callback_default_configuration = function() {
       # parameters with exp transformation and log inverse transformation
       # parameters with unknown inverse transformation
       # parameter set with trafo
-      if ("set_id" %in% names(ps())) {
-        # old paradox
-        has_logscale = map_lgl(instance$search_space$params, function(param) get_private(param)$.has_logscale)
-
-        has_trafo = map_lgl(instance$search_space$params, function(param) get_private(param)$.has_trafo)
-
-        has_extra_trafo = get_private(instance$search_space)$.has_extra_trafo
-      } else {
-        has_logscale = map_lgl(instance$search_space$params$.trafo, function(x) identical(x, exp))
-
-        has_trafo = map_lgl(instance$search_space$params$.trafo, function(x) !is.null(x) && !identical(x, exp))
-
-        has_extra_trafo = !is.null(instance$search_space$extra_trafo)
-      }
+      has_logscale = map_lgl(instance$search_space$params$.trafo, function(x) identical(x, exp))
+      has_trafo = map_lgl(instance$search_space$params$.trafo, function(x) !is.null(x) && !identical(x, exp))
+      has_extra_trafo = !is.null(instance$search_space$extra_trafo)
 
       if (any(has_trafo) || has_extra_trafo) {
         stop("Cannot evaluate default hyperparameter values. Search space contains transformation functions with unknown inverse function.")
